@@ -1,14 +1,23 @@
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
+from enum import Enum
 from typing import List, Optional, TypeVar, Union
 
-from ..ref import ResultReference
+from dataclasses_json import config
+
+from ..ref import Ref, ResultReference
 from ..serializer import Model
 
 T = TypeVar("T")
-StrOrRef = Union[str, ResultReference]
-ListOrRef = Union[List[T], ResultReference]
+StrOrRef = Union[str, ResultReference, Ref]
+ListOrRef = Union[List[T], ResultReference, Ref]
+
+
+@dataclass
+class AddedItem(Model):
+    id: str = field(metadata=config(field_name="id"))
+    index: int
 
 
 @dataclass
@@ -34,7 +43,13 @@ class FilterOperator(Model):
     operator: Operator
 
 
-class Operator:
+class Operator(Enum):
     AND = "AND"
     OR = "OR"
     NOT = "NOT"
+
+
+@dataclass
+class SetError(Model):
+    type: str
+    description: Optional[str] = None
